"""Module listing all jove observatories in EVE regions"""

REGION_OBS = {
    "Aridia": "https://evemaps.dotlan.net/map/Aridia/Bazadod,Chibi,Defsunun,Esubara,Fihrneh,Hoseen,Huna,Isid,Nema,Nouta,Pserz,Soza#npc-delta",
    "Branch": "http://evemaps.dotlan.net/map/Branch/KMC-WI:AH-B84:O-JPKH:CX-1XF:Q-NJZ4:Z-K495:52G-NZ:YG-82V:T-Q2DD:LRWD-B:M-HU4V:P7Z-R3:C-LP3N:J52-BH:SVB-RE:C-VGYO:NEH-CS:4DTQ-K:W-4FA9:2B7A-3:BU-IU4:I-7JR4#npc_delta",
    "Cache": "http://evemaps.dotlan.net/map/Cache/0LY-W1:I6-SYN:LMM7-L:M-CNUD:U-QMOA:JZ-B5Y:U93O-A:NG-M8K#npc_delta",
    "Catch": "http://evemaps.dotlan.net/map/Catch/25S-6P:3GD6-8:4-07MU:7LHB-Z:9-8GBA:AX-DOT:B-XJX4:E3-SDZ:EX-0LQ:F4R2-Q:F9E-KX:G-AOTH:GE-94X:I-8D0G:IS-R7P:JA-O6J:JWZ2-V:L7XS-5:OGL8-Q:SNFV-I:ZQ-Z3Y#npc_delta",
    "Cloud Ring": "http://evemaps.dotlan.net/map/Cloud_Ring/XT-R36:77-KDQ:O-IVNH:OU-X3P:6-4V20:8R-RTB:G8AD-C:MJYW-3:QA1-BT:28O-JY:X-M9ON#npc_delta",
    "Cobalt Edge": "http://evemaps.dotlan.net/map/Cobalt_Edge/FV-YEA:5E-EZC:Y-RAW3:X-41DA:E-BYOS:5HN-D6:E-B957:87-1PM:5ED-4E:FV1-RQ:L-Z9NB:DK0-N8:CHP-76:1GT-MA:HB-5L3#npc_delta",
    "Curse": "http://evemaps.dotlan.net/map/Curse/ES-UWY:G-G78S:J7A-UR:K-MGJ7:V7D-JD:Y-K50G#npc_delta",
    "Deklein": "http://evemaps.dotlan.net/map/Deklein/TXME-A:S-DN5M:MXX5-9:N-TFXK:33RB-O:E-FIC0:ZOYW-O:5W3-DG:3JN9-Q:MZ1E-P:XCBK-X:U-TJ7Y#npc_delta",
    "Delve": "http://evemaps.dotlan.net/map/Delve/Z3V-1W:HM-XR2:YZ9-F6:IP6V-X:D-W7F0:QY6-RK:ZXB-VC:8F-TK3:F-9PXR:KBAK-I:M-SRKS#npc_delta",
    "Detorid": "http://evemaps.dotlan.net/map/Detorid/0-G8NO:1KAW-T:3-LJW3:4NDT-W:5J4K-9:62O-UE:7-A6XV:9-02G0:9N-0HF:BOZ1-O:D-0UI0:E51-JE:PQRE-W:P7MI-T:GR-X26:L8-WNE:GC-LTF:NB-ALM:L-QQ6P:XA5-TY:RZ-PIY:TYB-69:T-0JWP:U-MFTL:S-51XG:Z-2Y2Y:SY-UWN:I-9GI1#npc_delta",
    "Esoteria": "http://evemaps.dotlan.net/map/Esoteria/G2-INZ:JAUD-V:D-FVI7:CR-0E5:F-UVBV:G-YZUX:6EK-BV:NIZJ-0:Q1-R7K:R-ARKN:SN9S-N:PE-H02:G-4H4C:HHE5-L:P9F-ZG:C-PEWN:IPX-H5:YRV-MZ#npc_delta",
    "Etherium Reach": "http://evemaps.dotlan.net/map/Etherium_Reach/9P-870:KGT3-6:KMH-J1:RO-0PZ:IRD-HU:4-QDIX:89-JPE:8KE-YS:3IK-7O:1PF-BC:WPV-JN:CT8K-0:F69O-M#npc_delta",
    "Fade": "http://evemaps.dotlan.net/map/Fade/O1Y-ED:X36Y-G:0-ARFO#npc_delta",
    "Feythabolis": "http://evemaps.dotlan.net/map/Feythabolis/UD-VZW:OXC-UL:X6-J6R:DUU1-K:K-X5AX:Z-PNIA:PO-3QW:U-BXU9:6O-XIO:2UK4-N:QK-CDG:2-F3OE:CL-J9W:UB5Z-3:3-BADZ:P8-BKO:I9-ZQZ:ZID-LE#npc_delta",
    "Fountain": "http://evemaps.dotlan.net/map/Fountain/AC2E-3:R3W-XU:SPLE-Y:Q-XEB3:JGOW-Y:KCT-0A:IGE-RI:Z9PP-H:7X-02R:6F-H3W:L-1SW8:CHA2-Q:UAYL-F:A-HZYL:H-S80W:15U-JY:HMF-9D:7BX-6F:P5-EFH:YRNJ-8:G-UTHL:I-CUVX:87XQ-0:V6-NY1:PXF-RF:Z-YN5Y#npc_delta",
    "Geminate": "http://evemaps.dotlan.net/map/Geminate/SR-KBB:FDZ4-A:WH-2EZ:QKTR-L:BWF-ZZ:4-CUM5:39-DGG:K42-IE:LX-ZOJ:6L78-1:L-TOFR:TJM-JJ:D-I9HJ:HKYW-T:4K0N-J:B-F1MI:O2O-2X:TDE4-H#npc_delta",
    "Great Wildlands": "http://evemaps.dotlan.net/map/Great_Wildlands/4M-P1I:7Q-8Z2:8DL-CP:B-VIP9:DE71-9:F5-CGW:HB-1NJ:IX8-JB:N-RAEL:NE-3GR:YUY-LM:Y4-GQV:UT-UZB:TET3-B:ZM-DNR:QQ3-YI:QM-20X:R-ESG0:UNJ-GX:V89M-R#npc_delta",
    "Immensea": "http://evemaps.dotlan.net/map/Immensea/NS2L-4:Y19P-1:O7-7UX:CJNF-J:AC-7LZ:Y-FZ5N:U9U-TQ:6-I162:Y-C4AL:FRTC-5:R-ORB7#npc_delta",
    "Impass": "http://evemaps.dotlan.net/map/Impass/4OIV-X:DY-40Z:E7VE-V:01TG-J:PZMA-E:Z-N9IP:6E-MOW:X-0CKQ:GU-9F4:DDI-B7#npc_delta",
    "Insmother": "http://evemaps.dotlan.net/map/Insmother/0-VG7A:1ZF-PJ:4CJ-AC:5-2PQU:5C-RPA:88A-RA:B-II34:C1G-XC:EKPB-3:EUU-4N:F3-8X2:F39H-1:GDHN-K:GK5Z-T:HL-VZX:KD-KPR:L5-UWT:O-7LAI:XQP-9C:V-QXXK:MOCW-2:N-O53U:N7-BIY:ZO-4AR:RD-FWY:VBPT-T#npc_delta",
    "Malpais": "http://evemaps.dotlan.net/map/Malpais/1NZV-7:7T-0QS:APES-G:DAI-SH:F-TQWO:GL6S-2:H-EBQG:HG-YEQ:IBOX-2:JA-G0T:N-YLOE:NBW-GD:NSI-MW:POQP-K:PWPY-4:QSCO-D:RUF3-O:S5W-1Z:VVB-QH:Y-XZA7:XTVZ-E:ZOPZ-6#npc_delta",
    "Oasa": "http://evemaps.dotlan.net/map/Oasa/MZLW-9:DGDT-3:IG-4OF:Y-770C:X-Z4JW:6U-MFQ:IO-R2S:U9SE-N:3-JG3X:KED-2O:U-RELP:HO4E-Q:X-CYNC:RJBC-I:XKM-DE:JXQJ-B#npc_delta",
    "Omist": "http://evemaps.dotlan.net/map/Omist/9MWZ-B:C-WPWH:KR8-27:M9-FIB:DJK-67:X-EHHD:L-AS00:99-0GS:H90-C9:Z-7OK1:OKEO-X:7-8EOE#npc_delta",
    "Outer Passage": "http://evemaps.dotlan.net/map/Outer_Passage/QHH-13:XUPK-Z:WIO-OL:YQM-P1:TFPT-U:QFRV-2:8-AA98:2ULC-J:0-4VQL:QOK-SX:KGCF-5:2WU-XT:J7X-VN:ZZK-VF:4AZV-W:MC4C-H:CNHV-M:N-I024:4O-ZRI#npc_delta",
    "Outer Ring": "http://evemaps.dotlan.net/map/Outer_Ring/C0T-77:F5FO-U:0-WVQS:JKJ-VJ:T-Z6J2:CT7-5V:A-5M31:0D-CHA#npc_delta",
    "Paragon Soul": "http://evemaps.dotlan.net/map/Paragon_Soul/ARBX-9:O-MCZR:H8-ZTO:3PPT-9:GQ2S-8:LD-2VL:O-N589#npc_delta",
    "Period Basis": "http://evemaps.dotlan.net/map/Period_Basis/TCAG-3:VQE-CN:E-DOF2:08S-39:RYQC-I:Z-M5A1#npc_delta",
    "Perrigen Falls": "http://evemaps.dotlan.net/map/Perrigen_Falls/XU7-CH:E-WMT7:LW-YEW:OP7-BP:PE-SAM:RY-2FX:H-29TM:BEG-RL:MJ-5F9:JZ-UQC:JPEZ-R:TAL1-3:4-1ECP:M4-KX5:J9A-BH:A1F-22:9-ZA4Z:O-QKSM:VWES-Y:SY-OLX:PFV-ZH:MTO2-2:0-U2M4#npc_delta",
    "Providence": "http://evemaps.dotlan.net/map/Providence/9UY4-H:FSW-3C:MH9C-S:QBL-BV:QR-K85:OXIY-V:D-6WS1:TU-O0T:GN7-XY:8P9-BM:N-RMSH:K1Y-5H:2V-CS5:HP-6Z6:I-MGAB#npc_delta",
    "Pure Blind": "http://evemaps.dotlan.net/map/Pure_Blind/KQK1-2:JC-YX8:12YA-2:U-INPD:WW-KGD:R-2R0G:5ZXX-K:4-ABS8:S-MDYI:RZC-16:UC3H-Y:RORZ-H:UI-8ZE#npc_delta",
    "Querious": "http://evemaps.dotlan.net/map/Querious/A3-LOG:O3L-95:TV8-HS:MKD-O8:A-BO4V:8B-SAJ:UYU-VV:W6V-VM:OGY-6D:UVHO-F:Z-UZZN:RF-CN3:KEJY-U:ED-L9T:E-VKJV:3D5K-R#npc_delta",
    "Scalding Pass": "http://evemaps.dotlan.net/map/Scalding_Pass/1QZ-Y9:2-KPW6:4E-EZS:6-KPAB:9PX2-F:F2-NXA:FYD-TO:GN-PDU:H5N-V7:IAK-JW:JLO-Z3:K7-LDX:X9V-15:Q-K2T7:LBC-AW:NSBE-L:WV0D-1:U2-28D:LQ-OAI:Q-NA5H:WFFE-4:V-F6DQ#npc_delta",
    "Stain": "http://evemaps.dotlan.net/map/Stain/LGK-VP:WHG2-7:Y1-UQ2:G-ME2K:FV-SE8:2IGP-1:37S-KO:A-GPTM:WEQT-K:42-UOW:UKYS-5:X5O1-L:TL-T9Z:B-G1LG:J-AYLV:CJF-1P:L6B-0N:6QBH-S:JU-UYK:4XW2-D:373Z-7:2B-3M4:LGL-SD:O-CT8N:XFBE-T#npc_delta",
    "Syndicate": "http://evemaps.dotlan.net/map/Syndicate/Poitot:FD-MLJ:6-CZ49:ZN0-SR:T-LIWS:5-T0PZ:617I-I:5-FGQI:BY-S36:0LTQ-C:9U-TTJ:KFR-ZE:5-VKCN:57-YRU:51-5XG:DUV-5Y:CIS-7X:EU0I-T:2G38-I#npc_delta",
    "Tenal": "http://evemaps.dotlan.net/map/Tenal/3DR-CR:EOY-BG:PNS7-J:KMV-CQ:S-1LIO:5-O8B1:WV-0R2:SZ6-TA:6OYQ-Z:A1RR-M:ZK-YQ3:Q1U-IU:7D-PAT:T-K10W#npc_delta",
    "Tenerifis": "http://evemaps.dotlan.net/map/Tenerifis/WB-AYY:BW-WJ2:3L3N-X:Y-ORBJ:H-HWQR:ZD1-Z2:FE-6YQ:PEK-8Z:KW-OAM:JI1-SY:16AM-3:Y-EQ0C:MS1-KJ:NZW-ZO:F-ZBO0:0P-U0Q:T-AKQZ:9-980U:ZO-P5K#npc_delta",
    "The Kalevala Expanse": "http://evemaps.dotlan.net/map/The_Kalevala_Expanse/JT2I-7:BVRQ-O:SH6X-F:TA9T-P:BM-VYZ:EPCD-D:LE-67X:6FS-CZ:HPV-RJ:C3J0-O:HD-HOZ:K76A-3:R1O-GN:86L-9F:J-OAH2#npc_delta",
    "The Spire": "http://evemaps.dotlan.net/map/The_Spire/HIK-MC:B9EA-G:E-BFLT:C6C-K9:ETO-OT:KPI-OW:K-XJJT:RXA-W1:P65-TA:K-YL9T:GTB-O4:H4X-0I:OTJ9-E:M-NP5O#npc_delta",
    "Tribute": "http://evemaps.dotlan.net/map/Tribute/C2X-M5:C8VC-S:F-749O:NJ4X-S:V0DF-2:SH1-6P:WH-JCA:S8-NSQ:XD-TOV:W-UQA5#npc_delta",
    "Vale of the Silent": "http://evemaps.dotlan.net/map/Vale_of_the_Silent/0MV-4W:1N-FJ8:1VK-6B:1W-0KS:5T-KM3:6WW-28:7-K5EL:FS-RFL:Q-R3GP:P3EN-E:S-NJBB:Z-8Q65:H-NOU5:XSQ-TF:MQ-O27:BR-6XP:VI2K-J:LS9B-9:ZA0L-U:O-LR1H:MGAM-4:JZV-F4#npc_delta",
    "Venal": "http://evemaps.dotlan.net/map/Venal/N-Q5PW:Y6-HPG:9-266Q:K3JR-J:N5Y-4N:92K-H2:AJCJ-1:HBD-CC:0-XIDJ:4RX-EE:9IPC-E:EK2-ET:2PLH-3:M2-2V1:OJ-CT4#npc_delta",
    "Wicked Creek": "http://evemaps.dotlan.net/map/Wicked_Creek/3Q-VZA:4-EFLU:5NQI-E:8-OZU1:EIH-IU:G9L-LP:GPD5-0:HD-AJ7:J7-BDX:JQU-KY:HPBE-D:U104-3:R0-DMM:J-RXYN:JEQG-7#npc_delta",
}
