"""Example plugin app for Alliance Auth."""

# pylint: disable = invalid-name
default_app_config = "evescout.apps.ExampleConfig"

__version__ = "1.1.1"

repo_url = "https://gitlab.com/r0kym/aa-evescout"
