# Generated by Django 4.2.16 on 2024-11-20 12:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("evescout", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="signaturepinger",
            name="ping_type",
            field=models.CharField(
                choices=[(" ", "None"), ("@here", "@here"), ("@everyone", "@everyone")],
                default=" ",
                help_text="Type of notification that should be sent out with the ping",
                max_length=9,
            ),
        ),
    ]
